@@ -524,6 +524,8 @@ class Overlap(InnerProduct):
         """
         Compute norm of a COMPLEX16Frequency Series
         """
+        if h.data.length != self.len1side:
+            print "Bad data length, needed %d, got %d" % (self.len1side, h.data.length)
         assert h.data.length == self.len1side
         assert abs(h.deltaF-self.deltaF) <= TOL_DF
         val = 0.
@@ -646,6 +648,46 @@ class ComplexOverlap(InnerProduct):
             tShift[i] -= self.len2side * self.deltaT
         return tShift
 
+def overlap(t1, t2, ovrlp, delta_f, f_low, approx1, approx2, t1_norm=None, t2_norm=None):
+    """
+    Calculate the overlap of template 1 using approx1 with template 2 using approx2 with frequency binning given by delta_f and beginning the integration at f_low. If t1_norm or t2_norm is given, it is not calculated, it is simply used and returned.
+    """
+
+    if isinstance(t1, lsctables.SnglInspiral):
+        h1 = generate_waveform_from_tmplt(t1, approx1, delta_f, f_low)
+    else:
+        h1 = t1
+
+    if isinstance(t2, lsctables.SnglInspiral):
+        h2 = generate_waveform_from_tmplt(t2, approx2, delta_f, f_low)
+    else:
+        h2 = t2
+
+    if t1_norm is None:
+        t1_norm = ovrlp.norm(h1)
+    if t2_norm is None:
+        t2_norm = ovrlp.norm(h2)
+
+    o12 = ovrlp.ip(h1, h2) / t1_norm / t2_norm
+
+    return o12, t1_norm, t2_norm
+
+
+# Adapted from similar code in gstlal.cbc_template_fir
+def generate_waveform_from_tmplt(tmplt, approximant, delta_f=0.125, f_low=40, amporder=-1, phaseorder=7):
+
+    params = ChooseWaveformParams(
+        deltaF = delta_f,
+        m1 = lal.MSUN_SI * tmplt.mass1, m2 = lal.MSUN_SI * tmplt.mass2,
+        s1x = tmplt.spin1x, s1y = tmplt.spin1y, s1z = tmplt.spin1z,
+        s2x = tmplt.spin2x, s2y = tmplt.spin2y, s2z = tmplt.spin2z,
+        fmin = f_low, fref = 0,
+        dist = 1.e6 * lal.PC_SI, # distance
+        ampO = amporder, phaseO = phaseorder,
+        approx = lalsim.GetApproximantFromString(str(approximant)),
+        taper = lalsim.SIM_INSPIRAL_TAPER_START # FIXME: don't hardcode
+    )
+    return hoff(params, Fp=1, Fc=1)
 
 #
 # Antenna pattern functions
@@ -669,13 +711,20 @@ def Fcross(theta, phi, psi):
 #
 # Mass parameter conversion functions - note they assume m1 >= m2
 #
+def norm_sym_ratio(eta):
+    # FIXME: Replace with isclose when available
+    if eta > 0.25:
+        np.testing.assert_almost_equal(0.25, eta)
+        eta = 0.25
+    return sqrt(1 - 4.*eta)
+
 def mass1(Mc, eta):
     """Compute larger component mass from Mc, eta"""
-    return 0.5*Mc*eta**(-3./5.)*(1. + sqrt(1 - 4.*eta))
+    return 0.5*Mc*eta**(-3./5.)*(1. + norm_sym_ratio(eta))
 
 def mass2(Mc, eta):
     """Compute smaller component mass from Mc, eta"""
-    return 0.5*Mc*eta**(-3./5.)*(1. - sqrt(1 - 4.*eta))
+    return 0.5*Mc*eta**(-3./5.)*(1. - norm_sym_ratio(eta))
 
 def mchirp(m1, m2):
     """Compute chirp mass from component masses"""
@@ -687,8 +736,8 @@ def symRatio(m1, m2):
 
 def m1m2(Mc, eta):
     """Compute component masses from Mc, eta. Returns m1 >= m2"""
-    m1 = 0.5*Mc*eta**(-3./5.)*(1. + sqrt(1 - 4.*eta))
-    m2 = 0.5*Mc*eta**(-3./5.)*(1. - sqrt(1 - 4.*eta))
+    m1 = 0.5*Mc*eta**(-3./5.)*(1. + norm_sym_ratio(eta))
+    m2 = 0.5*Mc*eta**(-3./5.)*(1. - norm_sym_ratio(eta))
     return m1, m2
 
 def Mceta(m1, m2):
@@ -865,6 +914,9 @@ def hoft(P, Fp=None, Fc=None):
         lalsim.SimInspiralREAL8WaveTaper(ht.data, P.taper)
     if P.deltaF is not None:
         TDlen = int(1./P.deltaF * 1./P.deltaT)
+        if TDlen < ht.data.length:
+            print "TD length requirement not met: Needed at most %d (%f s), got %d (%f s)" % (TDlen, TDlen*P.deltaT, ht.data.length, ht.data.length*ht.deltaT)
+            P.print_params()
         assert TDlen >= ht.data.length
         ht = lal.ResizeREAL8TimeSeries(ht, 0, TDlen)
     return ht
