@@ -211,7 +211,7 @@ INT4 LALInferenceFprintParameterNonFixedHeaders(FILE *out, LALInferenceVariables
 INT4 LALInferenceFprintParameterNonFixedHeadersWithSuffix(FILE *out, LALInferenceVariables *params, const char *suffix);
 
 /** Prints a variable item to a string (must be pre-allocated!) */
-void LALInferencePrintVariableItem(char *out, LALInferenceVariableItem *ptr);
+void LALInferencePrintVariableItem(char *out, const LALInferenceVariableItem *const ptr);
 
 /**
  * Return a pointer to the memory the variable \c vars is stored in specified by \c name
