@@ -269,7 +269,15 @@ static void LALInferenceInitCalibrationVariables(LALInferenceRunState *runState,
         LALInferenceRegisterUniformVariableREAL8(runState, currentParams, CA_A, zero, camp_min_A, camp_max_A, LALINFERENCE_PARAM_LINEAR);
         dataPtr = dataPtr->next;
       }
+
       LALInferenceAddVariable(currentParams, "constantcal_active", &calOn, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
+      /*If user specifies a width for the error prior, a gaussian prior will be used, otherwise a flat prior will be used*/
+      REAL8 ampUncertaintyPrior=-1.0;
+      ppt = LALInferenceGetProcParamVal(runState->commandLine, "--constcal_ampsigma");
+      if (ppt) {
+        ampUncertaintyPrior = atof(ppt->value);
+      }
+      LALInferenceAddVariable(runState->priorArgs, "constcal_amp_uncertainty", &ampUncertaintyPrior, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
     }
     if (LALInferenceGetProcParamVal(runState->commandLine, "--MarginalizeConstantCalPha")){
       /* Add linear calibration phase errors to the measurement. For the moment the prior ranges are the same for the three IFOs */
@@ -285,6 +293,15 @@ static void LALInferenceInitCalibrationVariables(LALInferenceRunState *runState,
         dataPtr = dataPtr->next;
       }
       LALInferenceAddVariable(currentParams, "constantcal_active", &calOn, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
+
+     /*If user specifies a width for the error prior, a gaussian prior will be used, otherwise a flat prior will be used*/
+      REAL8 phaseUncertaintyPrior=-1.0;
+      ppt = LALInferenceGetProcParamVal(runState->commandLine, "--constcal_phasigma");
+      if (ppt) {
+        phaseUncertaintyPrior = M_PI/180.0*atof(ppt->value); /* CL arg in degrees, variable in radians */
+      }
+      LALInferenceAddVariable(runState->priorArgs, "constcal_phase_uncertainty", &phaseUncertaintyPrior, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+
     }
   }
   else{
