@@ -527,7 +527,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
 
   int Nifos=0;
   for(dataPtr=data;dataPtr;dataPtr=dataPtr->next) Nifos++;
-  void **generatedFreqModels=alloca((1+Nifos)*sizeof(void *));
+  void *generatedFreqModels[1+Nifos];
   for(i=0;i<=Nifos;i++) generatedFreqModels[i]=NULL;
 
   //noise model meta parameters
@@ -1028,7 +1028,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
       XLALREAL8ReverseFFT(dh_S, dh_S_tilde, data->margFFTPlan);
 
       if (margphi) {
-          dh_S_phase_tilde->data[i] = crect( creal(dh_S_tilde->data[0]), 0.0);
+          dh_S_phase_tilde->data[0] = crect( creal(dh_S_phase_tilde->data[0]), 0.0);
           XLALREAL8ReverseFFT(dh_S_phase, dh_S_phase_tilde, data->margFFTPlan);
       }
 
@@ -1577,7 +1577,7 @@ void LALInferenceNetworkSNR(LALInferenceVariables *currentParams,
 
   int Nifos=0;
   for(dataPtr=data;dataPtr;dataPtr=dataPtr->next) Nifos++;
-  void **generatedFreqModels=alloca((1+Nifos)*sizeof(void *));
+  void *generatedFreqModels[1+Nifos];
   for(i=0;i<=Nifos;i++) generatedFreqModels[i]=NULL;
 
   //check if signal model is being used
