@@ -37,6 +37,47 @@ static double qInnerIntegrand(double M2, void *viData);
 static double etaInnerIntegrand(double M2, void *viData);
 static double outerIntegrand(double M1, void *voData);
 
+static REAL8 LALInferenceConstantCalibrationPrior(LALInferenceRunState *runState, LALInferenceVariables *params) {
+
+  LALInferenceIFOData *ifo = NULL;
+  REAL8 ampWidth = -1.0;
+  REAL8 phaseWidth = -1.0;
+  REAL8 logPrior = 0.0;
+
+  if (runState->commandLine == NULL || !(LALInferenceGetProcParamVal(runState->commandLine, "--MarginalizeConstantCalAmp"))|| !(LALInferenceGetProcParamVal(runState->commandLine, "--MarginalizeConstantCalPha"))) {
+    return logPrior;
+  }
+
+  ifo = runState->data;
+  do {
+
+    if((LALInferenceGetProcParamVal(runState->commandLine, "--MarginalizeConstantCalAmp"))){
+      ampWidth = *(REAL8 *)LALInferenceGetVariable(runState->priorArgs, "constcal_amp_uncertainty");
+      if (ampWidth>0){
+	      char ampVarName[VARNAME_MAX];
+	      REAL8 amp = 0.0;
+	      snprintf(ampVarName, VARNAME_MAX, "calamp_%s", ifo->name);
+	      amp = *(REAL8*)LALInferenceGetVariable(params, ampVarName);
+	      logPrior += -log(2.0*M_PI) - log(ampWidth) - 0.5*amp*amp/ampWidth/ampWidth;
+      }
+    }
+    if((LALInferenceGetProcParamVal(runState->commandLine, "--MarginalizeConstantCalPha"))){
+      phaseWidth = *(REAL8 *)LALInferenceGetVariable(runState->priorArgs, "constcal_phase_uncertainty");
+      if (phaseWidth>0){
+	      char phaseVarName[VARNAME_MAX];
+	      REAL8 phase = 0.0;
+	      snprintf(phaseVarName, VARNAME_MAX, "calpha_%s", ifo->name);   
+	      phase = *(REAL8 *)LALInferenceGetVariable(params, phaseVarName);
+	      logPrior += -log(2.0*M_PI) - log(phaseWidth) - 0.5*phase*phase/phaseWidth/phaseWidth;
+      }
+    }
+   
+    ifo = ifo->next;
+  } while (ifo);
+
+  return logPrior;
+}
+
 static REAL8 LALInferenceSplineCalibrationPrior(LALInferenceRunState *runState, LALInferenceVariables *params) {
   LALInferenceIFOData *ifo = NULL;
   REAL8 ampWidth = -1.0;
@@ -319,6 +360,10 @@ REAL8 LALInferenceInspiralPrior(LALInferenceRunState *runState, LALInferenceVari
     if(*(REAL8 *)LALInferenceGetVariable(priorParams,"MTotMax") < m1+m2)
       return -DBL_MAX;
 
+  if(LALInferenceCheckVariable(priorParams,"MTotMin"))
+    if(*(REAL8 *)LALInferenceGetVariable(priorParams,"MTotMin") > m1+m2)
+      return -DBL_MAX;
+  
   if(model != NULL &&
         LALInferenceCheckVariable(priorParams,"malmquist") &&
         *(UINT4 *)LALInferenceGetVariable(priorParams,"malmquist") &&
@@ -329,7 +374,7 @@ REAL8 LALInferenceInspiralPrior(LALInferenceRunState *runState, LALInferenceVari
 
   /* Calibration priors. */
   logPrior += LALInferenceSplineCalibrationPrior(runState, params);
-
+  logPrior += LALInferenceConstantCalibrationPrior(runState, params);
   /* Evaluate PSD prior (returns 0 if no PSD model) */
   logPrior += LALInferencePSDPrior(runState, params);
 
@@ -1154,7 +1199,7 @@ REAL8 LALInferenceInspiralSkyLocPrior(LALInferenceRunState *runState, LALInferen
 
   /* Calibration parameters */
   logPrior += LALInferenceSplineCalibrationPrior(runState, params);
-
+  logPrior += LALInferenceConstantCalibrationPrior(runState, params);
   return(logPrior);
 }
 
@@ -2069,12 +2114,13 @@ void LALInferenceDrawNameFromPrior( LALInferenceVariables *output,
       LALInferenceSetVariable(output, name, &val);
       break;
     }
-    case LALINFERENCE_gslMatrix_t:
+    //LALInferenceDrawFromPrior() does not handle gsl matrices properly at the moment
+    /*case LALINFERENCE_gslMatrix_t:
     {
       REAL8 val = tmp;
       LALInferenceSetVariable(output, name, &val);
       break;
-    }
+    }*/
     default:
       XLAL_ERROR_VOID(XLAL_EINVAL, "Trying to randomise a non-numeric parameter!");
       break;
